# Licensed to Elasticsearch B.V under one or more agreements.
# Elasticsearch B.V licenses this file to you under the Apache 2.0 License.
# See the LICENSE file in the project root for more information

package Search::Elasticsearch::Client::7_0::Direct::XPack;
$Search::Elasticsearch::Client::7_0::Direct::XPack::VERSION = '7.30_1'; # TRIAL

$Search::Elasticsearch::Client::7_0::Direct::XPack::VERSION = '7.301';
use Moo;
with 'Search::Elasticsearch::Client::7_0::Role::API';
with 'Search::Elasticsearch::Role::Client::Direct';
use namespace::clean;

__PACKAGE__->_install_api('xpack');

1;

=pod

=encoding UTF-8

=head1 NAME

Search::Elasticsearch::Client::7_0::Direct::XPack - Plugin providing XPack APIs for Search::Elasticsearch v7.x

=head1 VERSION

version 7.30_1

=head1 SYNOPSIS

    my $response = $es->xpack->info();

=head2 DESCRIPTION

This class extends the L<Search::Elasticsearch> client with a C<xpack>
namespace.

=head1 METHODS

=head2 C<info()>

    my $response = $es->xpack->info();

Provides general information about the installed X-Pack features.

See the L<info|https://www.elastic.co/guide/en/elasticsearch/reference/current/info-api.html>
for more information.

=head2 C<usage()>

    my $response = $es->xpack->usage();

Provides usage information about the installed X-Pack features.

See the L<usage|https://www.elastic.co/guide/en/elasticsearch/reference/current/usage-api.html>
for more information.

=head1 AUTHOR

Enrico Zimuel <enrico.zimuel@elastic.co>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2020 by Elasticsearch BV.

This is free software, licensed under:

  The Apache License, Version 2.0, January 2004

=cut

__END__

# ABSTRACT: Plugin providing XPack APIs for Search::Elasticsearch v7.x

